==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/BuildBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class BuildBuilder extends BuildFluentImpl<BuildBuilder> implements VisitableBuilder<Build,BuildBuilder> {

    BuildFluent<?> fluent;
    Boolean validationEnabled;

    public BuildBuilder() {
        this(true);
    }

    public BuildBuilder(Boolean validationEnabled) {
        this(new Build(), validationEnabled);
    }

    public BuildBuilder(BuildFluent<?> fluent) {
        this(fluent, true);
    }

    public BuildBuilder(BuildFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Build(), validationEnabled);
    }

    public BuildBuilder(BuildFluent<?> fluent,Build instance) {
        this(fluent, instance, true);
    }

    public BuildBuilder(BuildFluent<?> fluent,Build instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public BuildBuilder(Build instance) {
        this(instance,true);
    }

    public BuildBuilder(Build instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableBuild build() {
        EditableBuild buildable = new EditableBuild(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        BuildBuilder that = (BuildBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/BuildBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class BuildBuilder extends BuildFluentImpl<BuildBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Build,BuildBuilder> {

    BuildFluent<?> fluent;
    Boolean validationEnabled;

    public BuildBuilder() {
        this(true);
    }

    public BuildBuilder(Boolean validationEnabled) {
        this(new Build(), validationEnabled);
    }

    public BuildBuilder(BuildFluent<?> fluent) {
        this(fluent, true);
    }

    public BuildBuilder(BuildFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Build(), validationEnabled);
    }

    public BuildBuilder(BuildFluent<?> fluent,Build instance) {
        this(fluent, instance, true);
    }

    public BuildBuilder(BuildFluent<?> fluent,Build instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public BuildBuilder(Build instance) {
        this(instance,true);
    }

    public BuildBuilder(Build instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableBuild build() {
        EditableBuild buildable = new EditableBuild(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        BuildBuilder that = (BuildBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
